@@ -17,9 +17,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#define _GNU_SOURCE
+
 #include "mbexp.h"
 
-void 
+void /* Not Used  */
 mb_init(void)
 {
   /* XXXX init gtype system here ? */
@@ -618,7 +620,7 @@ mb_font_unref(MBFont* font)
 #elif defined (USE_XFT)
       ;
 #else
-      if (font->gc) XFreeGC(dpy, font->gc);
+      if (font->gc) XFreeGC(font->dpy, font->gc);
 #endif
 
       if (font->family) 
