@@ -17,8 +17,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#define _GNU_SOURCE   /* X11.pc sets -DXOPEN flag which this works round */
+
 #include "mbutil.h"
-#include <alloca.h>
 
 #define MAX_ARGS 255
 
